pm4py.statistics.overlap.interval\_events package
=================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.overlap.interval_events.log
   pm4py.statistics.overlap.interval_events.pandas

Module contents
---------------

.. automodule:: pm4py.statistics.overlap.interval_events
   :members:
   :undoc-members:
   :show-inheritance:
